"use strict";
// The module 'vscode' contains the VS Code extensibility API
// Import the module and reference it with the alias vscode in your code below
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.translate = translate;
const aws_1 = require("./aws");
const azure_1 = require("./azure");
const deepl_1 = require("./deepl");
const files_1 = require("./files");
const folderFiles_1 = require("./folderFiles");
const google_1 = require("./google");
const openai_1 = require("./openai");
const util_1 = require("./util");
function translate(sourceFile, config) {
    return __awaiter(this, void 0, void 0, function* () {
        var _a;
        // set the delimiters for named arguments
        const startDelimiter = config.startDelimiter || "{";
        if (startDelimiter) {
            util_1.Util.startDelimiter = startDelimiter;
        }
        const endDelimiter = config.endDelimiter || "}";
        if (endDelimiter) {
            util_1.Util.endDelimiter = endDelimiter;
        }
        let translateEngine;
        if (config.translationKeyInfo.kind === "google") {
            translateEngine = yield google_1.GoogleTranslate.initialize(config.translationKeyInfo.apiKey);
        }
        else if (config.translationKeyInfo.kind === "aws") {
            translateEngine = new aws_1.AWSTranslate(config.translationKeyInfo.accessKeyId, config.translationKeyInfo.secretAccessKey, config.translationKeyInfo.region);
        }
        else if (config.translationKeyInfo.kind === "azure") {
            translateEngine = new azure_1.AzureTranslate(config.translationKeyInfo.secretKey, config.translationKeyInfo.region);
        }
        else if (config.translationKeyInfo.kind === "deepLFree") {
            translateEngine = new deepl_1.DeepLTranslate(config.translationKeyInfo.secretKey, "free");
        }
        else if (config.translationKeyInfo.kind === "deepLPro") {
            translateEngine = new deepl_1.DeepLTranslate(config.translationKeyInfo.secretKey, "pro");
        }
        else if (config.translationKeyInfo.kind === "openai") {
            translateEngine = new openai_1.OpenAITranslate(config.translationKeyInfo.apiKey, config.translationKeyInfo.baseUrl, config.translationKeyInfo.model, config.translationKeyInfo.maxTokens, config.translationKeyInfo.temperature, config.translationKeyInfo.topP, config.translationKeyInfo.n, config.translationKeyInfo.presencePenalty, config.translationKeyInfo.frequencyPenalty);
        }
        else {
            console.warn("You must provide a Google, AWS, Azure, deepL, openai parameters first in the extension settings.");
            return;
        }
        const fileMode = (_a = config.mode) !== null && _a !== void 0 ? _a : "file";
        const files = readFiles(sourceFile, fileMode);
        if (files === null) {
            return;
        }
        // enforce source locale if provided in settings
        if (config.sourceLocale !== files.sourceLocale) {
            console.log(`You must use the ${config.sourceLocale}.json file due to your Source Locale setting.`);
            return;
        }
        const keepTranslations = config.keepTranslations === "keep";
        const keepExtras = config.keepExtraTranslations === "keep";
        // load source JSON
        let source;
        try {
            source = yield files.loadJsonFromLocale(files.sourceLocale);
        }
        catch (error) {
            if (error instanceof Error) {
                console.log(error, "Source file malformed");
            }
            return;
        }
        // Iterate target Locales
        for (const targetLocale of files.targetLocales) {
            try {
                const isValid = yield translateEngine.isValidLocale(targetLocale);
                if (!isValid) {
                    throw Error(`${targetLocale} is not supported. Skipping.`);
                }
                const targetOriginal = yield files.loadJsonFromLocale(targetLocale);
                // Iterate source terms
                const targetNew = yield recurseNode(source, targetOriginal, keepTranslations, keepExtras, files.sourceLocale, targetLocale, translateEngine, config.ignorePrefix);
                // save target
                files.saveJsonToLocale(targetLocale, targetNew);
                const feedback = `Translated locale '${targetLocale}'`;
                console.log(feedback);
            }
            catch (error) {
                if (error instanceof Error) {
                    console.error(error);
                }
                return;
            }
        }
    });
}
const readFiles = (filePath, mode) => {
    try {
        const files = mode === "file" ? new files_1.Files(filePath) : new folderFiles_1.FolderFiles(filePath);
        // log locale info
        console.log(`Source locale = ${files.sourceLocale}`);
        console.log(`Target locales = ${files.targetLocales}`);
        return files;
    }
    catch (error) {
        if (error instanceof Error) {
            console.error(error);
        }
        return null;
    }
};
function recurseNode(source_1, original_1, keepTranslations_1, keepExtras_1, sourceLocale_1, locale_1, translateEngine_1) {
    return __awaiter(this, arguments, void 0, function* (source, original, keepTranslations, keepExtras, sourceLocale, locale, translateEngine, ignorePrefix = "", isArray = false) {
        var _a;
        // biome-ignore lint/suspicious/noExplicitAny: array and object types are used for flexibility
        const destination = isArray ? [] : {};
        // defaults
        if (keepTranslations === null) {
            keepTranslations = true;
        }
        if (keepExtras === null) {
            keepExtras = true;
        }
        for (const term in source) {
            const node = source[term];
            if (node instanceof Object && node !== null) {
                destination[term] = yield recurseNode(node, (_a = original[term]) !== null && _a !== void 0 ? _a : {}, keepTranslations, keepExtras, sourceLocale, locale, translateEngine, ignorePrefix, Array.isArray(node));
            }
            else {
                // if we already have a translation, keep it
                if (keepTranslations && original[term]) {
                    destination[term] = original[term];
                }
                else if (typeof node === "number" || typeof node === "boolean") {
                    // numbers and booleans do not need translations
                    destination[term] = node;
                }
                else {
                    if (ignorePrefix === "" ||
                        (ignorePrefix !== "" && !term.startsWith(ignorePrefix))) {
                        const translation = yield translateEngine
                            .translateText(node, sourceLocale, locale)
                            .catch((err) => console.error(err));
                        destination[term] = translation;
                    }
                    else {
                        delete destination[term];
                    }
                }
            }
        }
        if (keepExtras) {
            // add back in any terms that were not in source
            for (const term in original) {
                if (!destination[term]) {
                    destination[term] = original[term];
                }
            }
        }
        return destination;
    });
}
